interface FillsFeedOptions {
    subscriptions?: FillsFeedSubscribeParams;
    reconnectIntervalMs?: number;
    reconnectionMaxAttempts?: number;
}
interface FillsFeedSubscribeParams {
    marketId?: string;
    marketIds?: string[];
    accountIds?: string[];
    headUpdates?: boolean;
}
interface FillEventUpdate {
    status: 'new' | 'revoke';
    marketKey: 'string';
    marketName: 'string';
    slot: number;
    writeVersion: number;
    event: {
        eventType: 'spot' | 'perp';
        maker: 'string';
        taker: 'string';
        takerSide: 'bid' | 'ask';
        timestamp: 'string';
        seqNum: number;
        makerClientOrderId: number;
        takerClientOrderId: number;
        makerFee: number;
        takerFee: number;
        price: number;
        quantity: number;
    };
}
interface HeadUpdate {
    head: number;
    previousHead: number;
    headSeqNum: number;
    previousHeadSeqNum: number;
    status: 'new' | 'revoke';
    marketKey: 'string';
    marketName: 'string';
    slot: number;
    writeVersion: number;
}
interface StatusMessage {
    success: boolean;
    message: string;
}
export declare class FillsFeed {
    private _url;
    private _socket;
    private _subscriptions?;
    private _connected;
    private _reconnectionIntervalMs;
    private _reconnectionAttempts;
    private _reconnectionMaxAttempts;
    private _onConnect;
    private _onDisconnect;
    private _onFill;
    private _onHead;
    private _onStatus;
    constructor(url: string, options?: FillsFeedOptions);
    private _reconnectionAttemptsExhausted;
    private _connect;
    subscribe(subscriptions: FillsFeedSubscribeParams): void;
    unsubscribe(marketId: string): void;
    connected(): boolean;
    onConnect(callback: () => void): void;
    onDisconnect(callback: () => void): void;
    onFill(callback: (update: FillEventUpdate) => void): void;
    onHead(callback: (update: HeadUpdate) => void): void;
    onStatus(callback: (update: StatusMessage) => void): void;
}
export {};
//# sourceMappingURL=fills.d.ts.map